"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runRemotes = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const child_process_1 = require("child_process");
const path_1 = require("path");
const chalk = require("chalk");
const DEFAULT_REMOTES_CONFIG_PATH = 'src/config/remotes.json';
function runRemotes(options, context) {
    var _a, _b, _c;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const p = context.projectsConfigurations.projects[context.projectName];
        const configPath = (_a = options.remoteConfigPath) !== null && _a !== void 0 ? _a : (0, path_1.join)(p.root, DEFAULT_REMOTES_CONFIG_PATH);
        const resolvedModuleFederationConfigPath = (0, path_1.resolve)(context.root, configPath);
        let moduleFederationConfig;
        try {
            moduleFederationConfig = require(resolvedModuleFederationConfigPath);
        }
        catch (_d) {
            throw new Error(`Could not load ${resolvedModuleFederationConfigPath}`);
        }
        const remotesToSkip = new Set((_b = options.skipRemotes) !== null && _b !== void 0 ? _b : []);
        const knownRemotes = Object.keys(moduleFederationConfig).filter((r) => !remotesToSkip.has(r));
        const remotePromises = knownRemotes.map((remote, index) => new Promise((resolve) => {
            const command = `npx nx run ${remote}:${context.targetName}${context.configurationName ? `:${context.configurationName}` : ''}`;
            const child = (0, child_process_1.exec)(command);
            const processExitListener = () => child.kill();
            process.on('exit', processExitListener);
            process.on('SIGTERM', processExitListener);
            child.stdout.on('data', (data) => {
                process.stdout.write(addColorAndPrefix(data, remote, index));
                // eslint-disable-next-line no-control-regex
                const raw = data.replace(/\u001b[^m]*?m/g, ''); // removing colors
                if (raw.includes('Network:')) {
                    // TODO
                    // The message "Network:  https://host:port" allows to determine when the remote is ready to be
                    // consumed by the Host.
                    resolve();
                }
            });
            child.stderr.on('data', (err) => {
                process.stderr.write(addColorAndPrefix(err, remote, index));
            });
            child.on('exit', () => {
                resolve();
            });
        }));
        yield Promise.all(remotePromises);
        const isDevServer = context.target.executor === 'qwik-nx:micro-frontends-dev-server';
        let skippedRemoteMessage = null;
        if ((_c = options.skipRemotes) === null || _c === void 0 ? void 0 : _c.length) {
            skippedRemoteMessage = `Skipped targets: ${options.skipRemotes.join(', ')}`;
        }
        devkit_1.output.success({
            title: 'Preliminary actions completed',
            bodyLines: [
                `Successfully instantiated "${context.targetName}" targets of ${context.projectName}'s remotes.`,
                skippedRemoteMessage,
                `Starting the ${context.projectName}'s ${isDevServer ? 'dev' : 'preview'} server..`,
            ].filter((v) => !!v),
        });
    });
}
exports.runRemotes = runRemotes;
function addColorAndPrefix(out, remoteName, index) {
    const availableBgColors = [
        'bgBlack',
        'bgRed',
        'bgGreen',
        'bgYellow',
        'bgBlue',
        'bgMagenta',
        'bgCyan',
        'bgWhite',
    ];
    const availableColors = [
        'black',
        'red',
        'green',
        'yellow',
        'blue',
        'magenta',
        'cyan',
        'white',
    ];
    out = out
        .split('\n')
        .map((l) => l.trim().length > 0 ? `${chalk.bold(remoteName.toUpperCase())} ${l}` : l)
        .join('\n');
    if (index < availableColors.length) {
        out = chalk[availableColors[index]](out);
    }
    else {
        out = chalk[availableBgColors[index % availableBgColors.length]](out);
    }
    return out;
}
//# sourceMappingURL=run-remotes.js.map