"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addE2eProject = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const get_installed_nx_version_1 = require("../../../utils/get-installed-nx-version");
const eslint_1 = require("@nx/eslint");
function addE2eProject(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (options.e2eTestRunner === 'cypress') {
            return addCypress(tree, options);
        }
        if (options.e2eTestRunner === 'playwright') {
            return addPlaywright(tree, options);
        }
        return () => void 0;
    });
}
exports.addE2eProject = addE2eProject;
function addCypress(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        (0, devkit_1.ensurePackage)('@nx/cypress', (0, get_installed_nx_version_1.getInstalledNxVersion)(tree));
        const { configurationGenerator } = yield Promise.resolve().then(() => require('@nx/cypress'));
        (0, devkit_1.addProjectConfiguration)(tree, options.e2eProjectName, {
            projectType: 'application',
            root: options.e2eProjectRoot,
            sourceRoot: (0, devkit_1.joinPathFragments)(options.e2eProjectRoot, 'src'),
            targets: {},
            tags: [],
            implicitDependencies: [options.projectName],
        });
        return yield configurationGenerator(tree, {
            project: options.e2eProjectName,
            directory: 'src',
            linter: options.linter,
            skipFormat: true,
            devServerTarget: `${options.projectName}:serve:development`,
        });
    });
}
function addPlaywright(tree, options) {
    var _a, _b;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        (0, devkit_1.ensurePackage)('@nx/playwright', (0, get_installed_nx_version_1.getInstalledNxVersion)(tree));
        const { configurationGenerator: playwrightConfigurationGenerator } = yield Promise.resolve().then(() => require('@nx/playwright'));
        (0, devkit_1.addProjectConfiguration)(tree, options.e2eProjectName, {
            projectType: 'application',
            root: options.e2eProjectRoot,
            sourceRoot: (0, devkit_1.joinPathFragments)(options.e2eProjectRoot, 'src'),
            targets: {},
            implicitDependencies: [options.projectName],
        });
        return yield playwrightConfigurationGenerator(tree, {
            project: options.e2eProjectName,
            skipFormat: true,
            directory: 'src',
            js: false,
            linter: (_a = options.linter) !== null && _a !== void 0 ? _a : eslint_1.Linter.EsLint,
            webServerCommand: `${(0, devkit_1.getPackageManagerCommand)().exec} nx serve ${options.projectName}`,
            webServerAddress: `http://localhost:${(_b = options.devServerPort) !== null && _b !== void 0 ? _b : 4200}`,
            setParserOptionsProject: true,
            skipPackageJson: false,
        });
    });
}
//# sourceMappingURL=add-e2e.js.map