"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.componentGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const add_styled_dependencies_1 = require("../../utils/add-styled-dependencies");
const ensure_file_utils_1 = require("../../utils/ensure-file-utils");
const normalize_options_1 = require("./utils/normalize-options");
function createComponentFiles(tree, options) {
    const libNames = (0, devkit_1.names)(options.name);
    const hasStyles = options.style && options.style !== 'none';
    const templateOptions = Object.assign(Object.assign(Object.assign({}, options), libNames), { hasStyles, importExportStatement: options.exportDefault
            ? libNames.className
            : `{ ${libNames.className} }` });
    (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files/common'), options.directory, templateOptions);
    if (hasStyles) {
        (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files/styles'), options.directory, templateOptions);
    }
    if (!options.skipTests) {
        (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files/tests'), options.directory, templateOptions);
    }
    if (options.generateStories) {
        (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files/storybook'), options.directory, templateOptions);
        (0, ensure_file_utils_1.ensureMdxTypeInTsConfig)(tree, options.project);
    }
}
function componentGenerator(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = (0, normalize_options_1.normalizeOptions)(tree, options);
        createComponentFiles(tree, normalizedOptions);
        yield (0, devkit_1.formatFiles)(tree);
        return (0, add_styled_dependencies_1.addStyledModuleDependencies)(tree, normalizedOptions.style);
    });
}
exports.componentGenerator = componentGenerator;
exports.default = componentGenerator;
//# sourceMappingURL=generator.js.map