"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hostGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const generator_1 = require("./../application/generator");
const generator_2 = require("../remote/generator");
const normalize_options_1 = require("../application/utils/normalize-options");
const path_1 = require("path");
const mf_beta_warning_1 = require("../../utils/mf-beta-warning");
function addFiles(tree, schema, remotes) {
    // TODO: switch to empty preset once available
    tree.delete((0, devkit_1.joinPathFragments)(schema.projectRoot, 'src/routes/flower/index.tsx'));
    tree.delete((0, devkit_1.joinPathFragments)(schema.projectRoot, 'src/routes/flower/flower.css'));
    (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files'), schema.projectRoot, {
        name: schema.projectName,
        remotes: remotes.map((r) => r.name),
    });
    tree.write((0, path_1.join)(schema.projectRoot, 'src/config/remotes.json'), JSON.stringify(Object.fromEntries(remotes.map((r) => [r.name, `http://localhost:${r.port}`]))));
    const projectConfig = (0, devkit_1.readProjectConfiguration)(tree, schema.projectName);
    projectConfig.targets['serve'].executor =
        'qwik-nx:micro-frontends-dev-server';
    projectConfig.targets['preview'].executor =
        'qwik-nx:micro-frontends-preview-server';
    (0, devkit_1.updateProjectConfiguration)(tree, schema.projectName, projectConfig);
}
function hostGenerator(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        (0, mf_beta_warning_1.addMicroFrontendBetaWarning)();
        const tasks = [];
        const normalizedSchema = yield (0, normalize_options_1.normalizeOptions)(tree, Object.assign(Object.assign({}, options), { devServerPort: options.port, previewServerPort: options.port }));
        const initTask = yield (0, generator_1.appGenerator)(tree, Object.assign(Object.assign({}, normalizedSchema), { skipFormat: true }));
        tasks.push(initTask);
        const remotesWithPorts = [];
        if (options.remotes) {
            let port = normalizedSchema.devServerPort + 1;
            for (const remote of options.remotes) {
                remotesWithPorts.push({
                    name: remote,
                    port,
                });
                yield (0, generator_2.default)(tree, Object.assign(Object.assign({}, options), { name: remote, port, skipFormat: true }));
                port++;
            }
        }
        addFiles(tree, normalizedSchema, remotesWithPorts);
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
        return (0, devkit_1.runTasksInSerial)(...tasks);
    });
}
exports.hostGenerator = hostGenerator;
exports.default = hostGenerator;
//# sourceMappingURL=generator.js.map