"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.angularInAppGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const path = require("path");
const init_1 = require("../../../utils/angular/init");
function normalizeOptions(tree, options) {
    var _a;
    const projectConfig = (0, devkit_1.readProjectConfiguration)(tree, options.project);
    return Object.assign(Object.assign({}, options), { installMaterialExample: options.installMaterialExample !== false, sourceRoot: (_a = projectConfig.sourceRoot) !== null && _a !== void 0 ? _a : projectConfig.root + '/src', projectRoot: projectConfig.root, projectType: projectConfig.projectType });
}
function addFiles(tree, normalizedOptions) {
    const filePath = normalizedOptions.installMaterialExample
        ? 'material'
        : 'demo';
    (0, devkit_1.generateFiles)(tree, path.join(__dirname, 'files', filePath), (0, devkit_1.joinPathFragments)(normalizedOptions.sourceRoot, 'routes/angular'), {});
}
function angularInAppGenerator(tree, schema) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = normalizeOptions(tree, schema);
        if (normalizedOptions.projectType !== 'application') {
            throw new Error(`Only applications are supported, "${normalizedOptions.project}" is a library.`);
        }
        const demoFilePath = (0, devkit_1.joinPathFragments)(normalizedOptions.sourceRoot, 'integrations/angular');
        if (tree.exists(demoFilePath)) {
            throw new Error(`Looks like angular integration has already been configured for ${normalizedOptions.project}. "${demoFilePath}" already exists.`);
        }
        const initCallback = (0, init_1.angularInit)(tree, {
            demoFilePath: (0, devkit_1.joinPathFragments)(normalizedOptions.sourceRoot, 'integrations/angular'),
            installMaterialExample: !!normalizedOptions.installMaterialExample,
            projectRoot: normalizedOptions.projectRoot,
            isApp: true,
        });
        addFiles(tree, normalizedOptions);
        if (!normalizedOptions.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
        return initCallback;
    });
}
exports.angularInAppGenerator = angularInAppGenerator;
exports.default = angularInAppGenerator;
//# sourceMappingURL=generator.js.map