"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cloudflarePagesIntegrationGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const integration_configuration_name_1 = require("../../../utils/integration-configuration-name");
const versions_1 = require("../../../utils/versions");
const migrations_1 = require("../../../utils/migrations");
function cloudflarePagesIntegrationGenerator(tree, options) {
    var _a, _b, _c;
    var _d;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const config = (0, devkit_1.readProjectConfiguration)(tree, options.project);
        if (config.projectType !== 'application') {
            throw new Error('Cannot setup cloudflare integration for the given project.');
        }
        if (!(0, migrations_1.isQwikNxProject)(config)) {
            throw new Error('Project contains invalid configuration.');
        }
        const configurationName = (0, integration_configuration_name_1.getIntegrationConfigurationName)(integration_configuration_name_1.IntegrationName.Cloudflare, config);
        const deployTargetName = config.targets['deploy']
            ? 'deploy.cloudflare'
            : 'deploy';
        const normalizedOptions = normalizeOptions(config);
        ((_b = (_a = config.targets['build']) === null || _a === void 0 ? void 0 : _a.configurations) !== null && _b !== void 0 ? _b : {})[configurationName] = {};
        ((_c = (_d = config.targets['build.ssr']).configurations) !== null && _c !== void 0 ? _c : (_d.configurations = {}))[configurationName] =
            getBuildSSRTargetCloudflareConfiguration(normalizedOptions);
        config.targets[deployTargetName] = getDeployTarget(normalizedOptions);
        config.targets['preview-cloudflare'] =
            getCloudflarePreviewTarget(normalizedOptions);
        config.targets['build-cloudflare'] = getIntermediateDependsOnTarget(normalizedOptions, configurationName);
        (0, devkit_1.updateProjectConfiguration)(tree, options.project, config);
        addFiles(tree, normalizedOptions);
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
        return addCloudflarePagesDependencies(tree);
    });
}
exports.cloudflarePagesIntegrationGenerator = cloudflarePagesIntegrationGenerator;
function getBuildSSRTargetCloudflareConfiguration(options) {
    return {
        configFile: `${options.projectConfig.root}/adapters/cloudflare-pages/vite.config.ts`,
    };
}
function getDeployTarget(options) {
    return {
        executor: '@k11r/nx-cloudflare-wrangler:deploy-page',
        options: {
            dist: `dist/${options.projectConfig.root}/client`,
        },
        dependsOn: ['build-cloudflare'],
    };
}
function getCloudflarePreviewTarget(options) {
    return {
        executor: '@k11r/nx-cloudflare-wrangler:serve-page',
        options: {
            dist: `dist/${options.projectConfig.root}/client`,
        },
        dependsOn: ['build-cloudflare'],
    };
}
/** Currently it's not possible to depend on a target with a specific configuration, that's why intermediate one is required */
function getIntermediateDependsOnTarget(options, configurationName) {
    return {
        executor: 'nx:run-commands',
        options: {
            command: `npx nx run ${options.projectConfig.name}:build:${configurationName}`,
        },
    };
}
function normalizeOptions(projectConfig) {
    return {
        projectConfig,
        offsetFromRoot: (0, devkit_1.offsetFromRoot)(projectConfig.root),
    };
}
function addFiles(tree, options) {
    const templateOptions = Object.assign(Object.assign({}, (0, devkit_1.names)(options.projectConfig.name)), { projectRoot: options.projectConfig.root, offsetFromRoot: options.offsetFromRoot });
    (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files'), options.projectConfig.root, templateOptions);
}
function addCloudflarePagesDependencies(tree) {
    return (0, devkit_1.addDependenciesToPackageJson)(tree, {}, {
        wrangler: versions_1.wranglerVersion,
        '@k11r/nx-cloudflare-wrangler': versions_1.nxCloudflareWrangler,
    });
}
exports.default = cloudflarePagesIntegrationGenerator;
//# sourceMappingURL=generator.js.map